@@ -1,6 +1,5 @@
 package Moonshine::Component;
 
-use 5.006;
 use strict;
 use warnings;
 
@@ -8,13 +7,12 @@ use Moonshine::Element;
 use Moonshine::Magic;
 use Params::Validate qw(:all);
 use Ref::Util qw(:all);
-use BEGIN::Lift;
 use feature qw/switch/;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
 extends "UNIVERSAL::Object";
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 BEGIN {
     my $fields = $Moonshine::Element::HAS{"attribute_list"}->();
@@ -146,7 +144,7 @@ Moonshine::Component - HTML Component base.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
